@@ -1,7 +1,8 @@
 from dataclasses import dataclass, field
 from typing import Dict, Optional, Type
 
-from ..data.global_options_base import GlobalOptionsBase
+from sym.shared.cli.data.global_options_base import GlobalOptionsBase
+
 from ..saml_clients.chooser import choose_saml_client
 from ..saml_clients.saml_client import SAMLClient
 
@@ -12,7 +13,6 @@ class GlobalOptions(GlobalOptionsBase):
         default_factory=lambda: choose_saml_client("auto", none_ok=True)
     )
     saml_clients: Dict[str, SAMLClient] = field(default_factory=dict)
-    log_dir: Optional[str] = None
     session_length: Optional[int] = None
     aws_region: Optional[str] = None
     disable_analytics: bool = False
