@@ -1,7 +1,7 @@
 import pytest
+from sym.shared.cli.tests.helpers.capture import CaptureCommand
 
 from sym.cli.saml_clients.aws_profile import AwsProfile
-from sym.cli.tests.helpers.capture import CaptureCommand
 from sym.cli.tests.saml_clients.conftest import TestContextFixture
 
 pytestmark = pytest.mark.usefixtures("click_context")
